@@ -2,7 +2,7 @@
 /**
  * Provides static methods for charset and locale safe string manipulation.
  *
- * Copyright 2003-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2003-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -66,8 +66,7 @@ class Horde_String
 
         if (is_array($input)) {
             $tmp = array();
-            reset($input);
-            while (list($key, $val) = each($input)) {
+            foreach ($input as $key => $val) {
                 $tmp[self::_convertCharset($key, $from, $to)] = self::convertCharset($val, $from, $to, $force);
             }
             return $tmp;
@@ -84,7 +83,7 @@ class Horde_String
 
             $input = clone $input;
             $vars = get_object_vars($input);
-            while (list($key, $val) = each($vars)) {
+            foreach ($vars as $key => $val) {
                 $input->$key = self::convertCharset($val, $from, $to, $force);
             }
             return $input;
@@ -485,6 +484,7 @@ class Horde_String
     )
     {
         if (Horde_Util::extensionExists('mbstring')) {
+            unset($php_errormsg);
             $track_errors = ini_set('track_errors', 1);
             $ret = @call_user_func('mb_' . $func, $haystack, $needle, $offset, self::_mbstringCharset($charset));
             ini_set('track_errors', $track_errors);
@@ -494,6 +494,7 @@ class Horde_String
         }
 
         if (Horde_Util::extensionExists('intl')) {
+            unset($php_errormsg);
             $track_errors = ini_set('track_errors', 1);
             $ret = self::convertCharset(
                 @call_user_func(
@@ -588,10 +589,18 @@ class Horde_String
     public static function wordwrap($string, $width = 75, $break = "\n",
                                     $cut = false, $line_folding = false)
     {
+        $breakRegex = '(?:' . preg_quote($break) . ')';
+        $rpos = self::rpos($break, "\n");
+        if ($rpos === false) {
+            $rpos = 0;
+        } else {
+            $rpos++;
+        }
         $wrapped = '';
+        $hasWrapped = false;
 
         while (self::length($string, 'UTF-8') > $width) {
-            $line = self::substr($string, 0, $width, 'UTF-8');
+            $line = self::substr($string, 0, $width + ($hasWrapped ? $rpos : 0), 'UTF-8');
             $string = self::substr($string, self::length($line, 'UTF-8'), null, 'UTF-8');
 
             // Make sure we didn't cut a word, unless we want hard breaks
@@ -602,39 +611,47 @@ class Horde_String
             }
 
             // Wrap at existing line breaks.
-            if (preg_match('/^(.*?)(\r?\n)(.*)$/su', $line, $match)) {
+            $regex = '/^(' . ($hasWrapped ? $breakRegex : '') . '.*?)(\r?\n)(.*)$/us';
+            if (preg_match($regex, $line, $match)) {
                 $wrapped .= $match[1] . $match[2];
                 $string = $match[3] . $string;
+                $hasWrapped = false;
                 continue;
             }
 
             // Wrap at the last colon or semicolon followed by a whitespace if
             // doing line folding.
             if ($line_folding &&
-                preg_match('/^(.*?)(;|:)(\s+.*)$/u', $line, $match)) {
-                $wrapped .= $match[1] . $match[2] . $break;
-                $string = $match[3] . $string;
+                preg_match('/^(.*?)(;|:)(\s+.*)$/us', $line, $match)) {
+                $wrapped .= $match[1] . $match[2];
+                $string = $break . $match[3] . $string;
+                $hasWrapped = true;
                 continue;
             }
 
             // Wrap at the last whitespace of $line.
             $sub = $line_folding
-                ? '(.+[^\s])'
-                : '(.*)';
+                ? '(' . ($hasWrapped ? $breakRegex : '') . '.+[^\s])'
+                : '(' . ($hasWrapped ? $breakRegex : '') . '.*)';
 
             if (preg_match('/^' . $sub . '(\s+)(.*)$/u', $line, $match)) {
-                $wrapped .= $match[1] . $break;
-                $string = ($line_folding ? $match[2] : '') . $match[3] . $string;
+                $wrapped .= $match[1];
+                $string = $break . ($line_folding ? $match[2] : '')
+                    . $match[3] . $string;
+                $hasWrapped = true;
                 continue;
             }
 
             // Hard wrap if necessary.
             if ($cut) {
-                $wrapped .= $line . $break;
+                $wrapped .= $line;
+                $string = $break . $string;
+                $hasWrapped = true;
                 continue;
             }
 
             $wrapped .= $line;
+            $hasWrapped = false;
         }
 
         return $wrapped . $string;
@@ -827,9 +844,13 @@ class Horde_String
     {
         $text = strval($text);
 
+        // First check for illegal surrogate pair sequences. See RFC 3629.
+        if (preg_match('/\xE0[\x80-\x9F][\x80-\xBF]|\xED[\xA0-\xBF][\x80-\xBF]/S', $text)) {
+            return false;
+        }
+
         for ($i = 0, $len = strlen($text); $i < $len; ++$i) {
             $c = ord($text[$i]);
-
             if ($c > 128) {
                 if ($c > 247) {
                     // STD 63 (RFC 3629) eliminates 5 & 6-byte characters.
