@@ -170,7 +170,7 @@ class Horde_Util_StringTest extends PHPUnit_Framework_TestCase
             39,
             Horde_String::length('I can eat glass and it doesn\'t hurt me.', 'utf-8'));
 
-        // Norsk/Norwegian/Nynorsk 33 
+        // Norsk/Norwegian/Nynorsk 33
         $this->assertEquals(
             33,
             Horde_String::length('Eg kan eta glas utan å skada meg.', 'utf-8'));
@@ -485,7 +485,16 @@ Lörem ipsüm dölör sit ämet,
   mäüris ämet.
 EOT
 ,
-            Horde_String::wordwrap($string, 30, "\n  "));
+            Horde_String::wordwrap($string, 31, "\n  "));
+        $this->assertEquals(
+<<<EOT
+Lörem ipsüm dölör sit ämet,
+  cönsectetüer ädipiscing
+  elit. Aliqüäm söllicitüdin
+  fäücibüs mäüris ämet.
+EOT
+,
+            Horde_String::wordwrap($string, 29, "\n  "));
 
         // Test existing line breaks.
         $string = "Lörem ipsüm dölör sit ämet, cönsectetüer ädipiscing elit.\nAliqüäm söllicitüdin fäücibüs mäüris ämet.";
@@ -572,7 +581,7 @@ sitämet,
 ipiscingelit.
 EOT
 ,
-            Horde_String::wordwrap($string, 15, "\n", true, 'utf-8', true));
+            Horde_String::wordwrap($string, 15, "\n", true, true));
         $string = "Lörem ipsüm dölör sit ämet,  cönsectetüer ädipiscing elit.  Aliqüäm söllicitüdin fäücibüs mäüris ämet.";
         $this->assertEquals(
 <<<EOT
@@ -582,7 +591,7 @@ Lörem ipsüm dölör sit ämet,
  mäüris ämet.
 EOT
 ,
-            Horde_String::wordwrap($string, 31, "\n", false, 'utf-8', true));
+            Horde_String::wordwrap($string, 31, "\n", false, true));
         $string = "Lörem ipsüm dölör sit; ämet:  cönsectetüer ädipiscing elit.  Aliqüäm söllicitüdin fäücibüs mäüris ämet.";
         $this->assertEquals(
 <<<EOT
@@ -593,7 +602,7 @@ Lörem ipsüm dölör sit;
  mäüris ämet.
 EOT
 ,
-            Horde_String::wordwrap($string, 31, "\n", false, 'utf-8', true));
+            Horde_String::wordwrap($string, 31, "\n", false, true));
         $string = "Lörem ipsüm dölör sit; ämet:cönsectetüer ädipiscing elit.  Aliqüäm söllicitüdin fäücibüs mäüris ämet.";
         $this->assertEquals(
 <<<EOT
@@ -603,7 +612,7 @@ Lörem ipsüm dölör sit;
  fäücibüs mäüris ämet.
 EOT
 ,
-            Horde_String::wordwrap($string, 31, "\n", false, 'utf-8', true));
+            Horde_String::wordwrap($string, 31, "\n", false, true));
         $string = "Lörem ipsüm dölör sit; ämet;  cönsectetüer ädipiscing elit.  Aliqüäm söllicitüdin fäücibüs mäüris ämet.";
         $this->assertEquals(
 <<<EOT
@@ -614,7 +623,7 @@ Lörem ipsüm dölör sit;
  mäüris ämet.
 EOT
 ,
-            Horde_String::wordwrap($string, 31, "\n", false, 'utf-8', true));
+            Horde_String::wordwrap($string, 31, "\n", false, true));
         $string = "Lörem ipsüm dölör sit; ämet;cönsectetüer ädipiscing elit.  Aliqüäm söllicitüdin fäücibüs mäüris ämet.";
         $this->assertEquals(
 <<<EOT
@@ -624,7 +633,17 @@ Lörem ipsüm dölör sit;
  fäücibüs mäüris ämet.
 EOT
 ,
-            Horde_String::wordwrap($string, 31, "\n", false, 'utf-8', true));
+            Horde_String::wordwrap($string, 31, "\n", false, true));
+
+        $string = 'the path to the configuration file for the components script (default : /Users/janschneider/Source/horde/components/lib/Components/../../config/conf.php)."';
+        $this->assertEquals(
+            <<<EOT
+the path to the configuration file for the components script (default :
+      /Users/janschneider/Source/horde/components/lib/Components/../../config/conf.php)."
+EOT
+            ,
+            Horde_String::wordwrap($string, 75, "\n      ")
+        );
     }
 
     public function testCommon()
